#[non_exhaustive]pub enum EncryptionScheme<'a> {
Pbes1(Algorithm),
Pbes2(Parameters<'a>),
}Expand description
Supported PKCS#5 password-based encryption schemes.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Pbes1(Algorithm)
Password-Based Encryption Scheme 1 as defined in RFC 8018 Section 6.1.
Pbes2(Parameters<'a>)
Password-Based Encryption Scheme 2 as defined in RFC 8018 Section 6.2.
Implementations
Sourceimpl<'a> EncryptionScheme<'a>
impl<'a> EncryptionScheme<'a>
Sourcepub fn decrypt(
&self,
password: impl AsRef<[u8]>,
ciphertext: &[u8],
) -> Result<Vec<u8>>
pub fn decrypt( &self, password: impl AsRef<[u8]>, ciphertext: &[u8], ) -> Result<Vec<u8>>
Attempt to decrypt the given ciphertext, allocating and returning a byte vector containing the plaintext.
Sourcepub fn decrypt_in_place<'b>(
&self,
password: impl AsRef<[u8]>,
buffer: &'b mut [u8],
) -> Result<&'b [u8]>
pub fn decrypt_in_place<'b>( &self, password: impl AsRef<[u8]>, buffer: &'b mut [u8], ) -> Result<&'b [u8]>
Attempt to decrypt the given ciphertext in-place using a key derived from the provided password and this scheme’s parameters.
Returns an error if the algorithm specified in this scheme’s parameters is unsupported, or if the ciphertext is malformed (e.g. not a multiple of a block mode’s padding)
Sourcepub fn encrypt(
&self,
password: impl AsRef<[u8]>,
plaintext: &[u8],
) -> Result<Vec<u8>>
pub fn encrypt( &self, password: impl AsRef<[u8]>, plaintext: &[u8], ) -> Result<Vec<u8>>
Encrypt the given plaintext, allocating and returning a vector containing the ciphertext.
Sourcepub fn encrypt_in_place<'b>(
&self,
password: impl AsRef<[u8]>,
buffer: &'b mut [u8],
pos: usize,
) -> Result<&'b [u8]>
pub fn encrypt_in_place<'b>( &self, password: impl AsRef<[u8]>, buffer: &'b mut [u8], pos: usize, ) -> Result<&'b [u8]>
Encrypt the given ciphertext in-place using a key derived from the provided password and this scheme’s parameters.
Sourcepub fn oid(&self) -> ObjectIdentifier
pub fn oid(&self) -> ObjectIdentifier
Get the ObjectIdentifier (a.k.a OID) for this algorithm.
Sourcepub fn pbes1(&self) -> Option<&Algorithm>
pub fn pbes1(&self) -> Option<&Algorithm>
Get pbes1::Parameters if it is the selected algorithm.
Sourcepub fn pbes2(&self) -> Option<&Parameters<'a>>
pub fn pbes2(&self) -> Option<&Parameters<'a>>
Get pbes2::Parameters if it is the selected algorithm.